@@ -1,7 +1,7 @@
 /* libspectrum.c: Some general routines
-   Copyright (c) 2001-2009 Philip Kendall, Darren Salt, Fredrick Meunier
+   Copyright (c) 2001-2015 Philip Kendall, Darren Salt, Fredrick Meunier
 
-   $Id: libspectrum.c 4830 2012-12-30 21:37:36Z fredm $
+   $Id: libspectrum.c 5422 2016-04-29 12:54:59Z fredm $
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@
 #include <gcrypt.h>
 
 /* The version of libgcrypt that we need */
-static const char *MIN_GCRYPT_VERSION = "1.1.42";
+static const char * const MIN_GCRYPT_VERSION = "1.1.42";
 
 #endif				/* #ifdef HAVE_GCRYPT_H */
 
@@ -566,6 +566,9 @@ libspectrum_identify_file_raw( libspectrum_id_t *type, const char *filename,
       { LIBSPECTRUM_ID_DISK_OPD,      "opd", 3, NULL,		    0, 0, 0 },
       { LIBSPECTRUM_ID_DISK_OPD,      "opu", 3, NULL,		    0, 0, 0 },
 
+      { LIBSPECTRUM_ID_DISK_D80,      "d80", 3, NULL,		    0, 0, 0 },
+      { LIBSPECTRUM_ID_DISK_D80,      "d40", 3, NULL,		    0, 0, 0 },
+
       { LIBSPECTRUM_ID_AUX_POK,       "pok", 3, NULL,		    0, 0, 0 },
 
       { -1, NULL, 0, NULL, 0, 0, 0 }, /* End marker */
@@ -693,6 +696,9 @@ libspectrum_identify_class( libspectrum_class_t *libspectrum_class,
   case LIBSPECTRUM_ID_DISK_OPD:
     *libspectrum_class = LIBSPECTRUM_CLASS_DISK_OPUS; return 0;
 
+  case LIBSPECTRUM_ID_DISK_D80:
+    *libspectrum_class = LIBSPECTRUM_CLASS_DISK_DIDAKTIK; return 0;
+
   case LIBSPECTRUM_ID_DISK_SCL:
   case LIBSPECTRUM_ID_DISK_TRD:
     *libspectrum_class = LIBSPECTRUM_CLASS_DISK_TRDOS; return 0;
@@ -871,7 +877,7 @@ libspectrum_uncompress_file( unsigned char **new_buffer, size_t *new_length,
 #else				/* #ifndef __MORPHOS__ */
               if( xfdDecrunchBuffer( xfdobj ) ) {
 #endif				/* #ifndef __MORPHOS__ */
-                *new_buffer = libspectrum_malloc( xfdobj->xfdbi_TargetBufSaveLen );
+                *new_buffer = libspectrum_new( char, xfdobj->xfdbi_TargetBufSaveLen );
                 *new_length = xfdobj->xfdbi_TargetBufSaveLen;
                 memcpy( *new_buffer, xfdobj->xfdbi_TargetBuffer, *new_length );
 #ifndef __MORPHOS__
@@ -921,7 +927,7 @@ libspectrum_uncompress_file( unsigned char **new_buffer, size_t *new_length,
 }
 
 /* Ensure there is room for `requested' characters after the current
-   position `ptr' in `buffer'. If not, realloc() and update the
+   position `ptr' in `buffer'. If not, renew() and update the
    pointers as necessary */
 void
 libspectrum_make_room( libspectrum_byte **dest, size_t requested,
@@ -932,7 +938,7 @@ libspectrum_make_room( libspectrum_byte **dest, size_t requested,
   if( *allocated == 0 ) {
 
     (*allocated) = requested;
-    *dest = libspectrum_malloc( requested * sizeof( **dest ) );
+    *dest = libspectrum_new( libspectrum_byte, requested );
 
   } else {
     current_length = *ptr - *dest;
@@ -947,7 +953,7 @@ libspectrum_make_room( libspectrum_byte **dest, size_t requested,
       current_length + requested :
       2 * (*allocated);
 
-    *dest = libspectrum_realloc( *dest, *allocated * sizeof( **dest ) );
+    *dest = libspectrum_renew( libspectrum_byte, *dest, *allocated );
   }
 
   /* Update the secondary pointer to the block */
