@@ -1,7 +1,7 @@
 /* make-perl.c: Generate a perl script to create the libspectrum_* typedefs
-   Copyright (c) 2002-2003 Philip Kendall, Darren Salt
+   Copyright (c) 2002-2003,2015 Philip Kendall, Darren Salt
 
-   $Id: make-perl.c 4796 2012-12-26 10:36:57Z fredm $
+   $Id: make-perl.c 5422 2016-04-29 12:54:59Z fredm $
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -115,11 +115,13 @@ int main(void)
 
 #ifdef HAVE_LIB_GLIB		/* #ifdef HAVE_LIB_GLIB */
 
-  printf( "  $_ = '';\n\n" );
+  printf( "  $_ = \"#define LIBSPECTRUM_HAS_GLIB_REPLACEMENT 0\\n\"\n" );
 
 #else				/* #ifdef HAVE_LIB_GLIB */
 
   printf( "  $_ = << \"CODE\";\n"
+"#define LIBSPECTRUM_HAS_GLIB_REPLACEMENT 1\n"
+"\n"
 "#ifndef	FALSE\n"
 "#define	FALSE	(0)\n"
 "#endif\n"
