@@ -1,7 +1,7 @@
 /* tape.c: Routines for handling tape files
-   Copyright (c) 2001-2008 Philip Kendall, Darren Salt, Fredrick Meunier
+   Copyright (c) 2001-2014 Philip Kendall, Darren Salt, Fredrick Meunier
 
-   $Id: tape.c 4436 2011-05-14 14:10:07Z fredm $
+   $Id: tape.c 5422 2016-04-29 12:54:59Z fredm $
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -130,7 +130,7 @@ data_block_edge( libspectrum_tape_data_block *block,
 libspectrum_tape*
 libspectrum_tape_alloc( void )
 {
-  libspectrum_tape *tape = libspectrum_malloc( sizeof( *tape ) );
+  libspectrum_tape *tape = libspectrum_new( libspectrum_tape, 1 );
   tape->blocks = NULL;
   tape->last_block = NULL;
   libspectrum_tape_iterator_init( &(tape->state.current_block), tape );
@@ -499,6 +499,9 @@ libspectrum_tape_get_next_edge_internal( libspectrum_dword *tstates,
       if( libspectrum_tape_iterator_current( it->current_block ) == NULL ) {
 	*flags |= LIBSPECTRUM_TAPE_FLAGS_STOP;
         *flags |= LIBSPECTRUM_TAPE_FLAGS_TAPE;
+        /* Need to have an edge at the end of the tape to terminate the last
+           pulse so clear the NO_EDGE flag if it has been set */
+        *flags &= ~LIBSPECTRUM_TAPE_FLAGS_NO_EDGE;
         libspectrum_tape_iterator_init( &(it->current_block), tape );
       }
     }
